#! /usr/bin/env python
"""
    Usage: cat min_below_minus_40.txt | ./process_consecutive.py

    Reads temperature data in this format:

    1946-12-06	-42.5	-36.5	-31.5
    1946-12-07	-45.6	-42.4	-38.6
    1946-12-08	-49.5	-47.1	-39.6

    (date, min, avg, max)

    Finds coldest periods by windows

    Copyright (C) Christopher Swingley <cswingle@gmail.com> and
    licensed under the terms of the GNU General Public License
    version 2.
"""

import sys
import datetime
from operator import itemgetter

WINDOW = 16

def get_average(arr):
    # print arr
    sum = 0.0
    count = 0
    for a in arr:
        sum += a
        count += 1
    return(sum/count)

avg_window = []
results = {}
for line in sys.stdin.readlines():
    line = line.strip()
    (date, min, avg, max) = line.split()
    if max == r'\N':
        max = (float(avg) - float(min)) + float(avg)
    if min == r'\N':
        min = (float(max) - float(avg)) + float(avg)
    (year, month, day) = date.split('-')
    (year, month, day) = map(int, (year, month, day))
    (min, avg, max) = map(float, (min, avg, max))
    current_date = datetime.date(year, month, day)
    if len(avg_window) < WINDOW:
        avg_window.insert(0, avg)
    else:
        avg_window.pop()
        avg_window.insert(0, avg)
        curr_avg = get_average(avg_window)
        results["%s - %s" % (current_date - datetime.timedelta(WINDOW - 1), current_date)] = curr_avg

sorted_results = sorted(results.iteritems(), key=itemgetter(1))

rank = 1
for result in sorted_results:
    (interval, avg) = result
    print "%5d  %s  %6.2f" % (rank, interval, avg)
    rank += 1

